package com.example.uikit

import android.annotation.SuppressLint
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.safeDrawingPadding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Icon
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import com.example.core.component.button.AppButton
import com.example.core.component.button.BubbleButton
import com.example.core.component.button.BubbleButtonState
import com.example.core.component.button.ButtonState
import com.example.core.component.button.CartButton
import com.example.core.component.button.LoginButton
import com.example.core.component.button.OutlinedAppButton
import com.example.core.component.button.SecondaryAppButton
import com.example.core.component.card.CartCard
import com.example.core.component.card.PrimaryCard
import com.example.core.component.card.ProjectCard
import com.example.core.component.header.BigHeader
import com.example.core.component.header.SmallHeader
import com.example.core.component.input.EnterInputField
import com.example.core.component.search.AppSearchField
import com.example.core.component.select.AppSelector
import com.example.core.component.select.Option
import com.example.core.component.tabbar.BottomTabBar
import com.example.core.component.tabbar.Catalog
import com.example.core.component.tabbar.Home
import com.example.core.component.tabbar.Profile
import com.example.core.component.tabbar.Projects
import com.example.core.theme.CustomIcons
import com.example.core.theme.CustomTheme

class MainActivity : ComponentActivity() {
    @SuppressLint("UnusedMaterial3ScaffoldPaddingParameter")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            CustomTheme {
                Scaffold { tabPadding ->
                    var currentDestination by rememberSaveable { mutableStateOf("com.example.core.component.tabbar.Home") }
                    Scaffold(
                        bottomBar = {
                            BottomTabBar(
                                tabs = listOf(Home, Catalog, Projects, Profile),
                                hierarchy = sequenceOf(currentDestination),
                                onTabClick = {
                                    currentDestination = it::class.qualifiedName.toString()
                                },
                                bottomPadding = tabPadding.calculateBottomPadding()
                            )
                        },
                        containerColor = CustomTheme.colors.white
                    ) {
                        Column(
                            modifier = Modifier
                                .safeDrawingPadding()
                                .fillMaxSize()
                                .padding(horizontal = 16.dp)
                                .background(CustomTheme.colors.white)
                                .verticalScroll(rememberScrollState()),
                            verticalArrangement = Arrangement.spacedBy(
                                15.dp,
                                alignment = Alignment.CenterVertically
                            ),
                            horizontalAlignment = Alignment.CenterHorizontally
                        ) {
                            Text(text = "Инпуты", style = CustomTheme.typography.title1ExtraBold)
                            var fieldValue1 by rememberSaveable { mutableStateOf("") }
                            var errorMessage1 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue1,
                                onValueChange = {
                                    fieldValue1 = it
                                    errorMessage1 = ""
                                },
                                errorMessage = errorMessage1,
                                label = "",
                                hint = "Введите имя"
                            )

                            var fieldValue2 by rememberSaveable { mutableStateOf("Иван") }
                            var errorMessage2 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue2,
                                onValueChange = {
                                    fieldValue2 = it
                                    errorMessage2 = ""
                                },
                                errorMessage = errorMessage2,
                                label = "",
                                hint = "Введите имя"
                            )

                            var fieldValue3 by rememberSaveable { mutableStateOf("") }
                            var errorMessage3 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue3,
                                onValueChange = {
                                    fieldValue3 = it
                                    errorMessage3 = ""
                                },
                                errorMessage = errorMessage3,
                                label = "Имя",
                                hint = "Введите имя"
                            )

                            var fieldValue4 by rememberSaveable { mutableStateOf("") }
                            var errorMessage4 by rememberSaveable { mutableStateOf("Введите ваше имя") }
                            EnterInputField(
                                value = fieldValue4,
                                onValueChange = {
                                    fieldValue4 = it
                                    errorMessage4 = ""
                                },
                                errorMessage = errorMessage4,
                                label = "Имя",
                                hint = "Введите имя"
                            )

                            var fieldValue5 by rememberSaveable { mutableStateOf("") }
                            var errorMessage5 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue5,
                                onValueChange = {
                                    fieldValue5 = it
                                    errorMessage5 = ""
                                },
                                errorMessage = errorMessage5,
                                label = "Имя",
                                hint = "Введите имя"
                            )

                            var fieldValue6 by rememberSaveable { mutableStateOf("Введите имя") }
                            var errorMessage6 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue6,
                                onValueChange = {
                                    fieldValue6 = it
                                    errorMessage6 = ""
                                },
                                errorMessage = errorMessage6,
                                label = "Имя",
                                hint = "Введите имя"
                            )

                            var fieldValue7 by rememberSaveable { mutableStateOf("123456789") }
                            var errorMessage7 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue7,
                                onValueChange = {
                                    fieldValue7 = it
                                    errorMessage7 = ""
                                },
                                errorMessage = errorMessage7,
                                label = "",
                                isPassword = true,
                                hint = "Введите имя"
                            )

                            var fieldValue8 by rememberSaveable { mutableStateOf("") }
                            var errorMessage8 by rememberSaveable { mutableStateOf("") }
                            EnterInputField(
                                value = fieldValue8,
                                onValueChange = {
                                    fieldValue8 = it
                                    errorMessage8 = ""
                                },
                                errorMessage = errorMessage8,
                                label = "",
                                hint = "--.--.----"
                            )
                            /*
                            * F6.user5@local.ru
                            * Pa$$w0rd
                            * */

                            Text(text = "Селекты", style = CustomTheme.typography.title1ExtraBold)

                            var selectedOption1 by remember { mutableStateOf<Option?>(null) }

                            AppSelector(
                                selectedOption = selectedOption1,
                                options = listOf(
                                    Option(label = "Мужской"),
                                    Option(label = "Женский")
                                ),
                                onOptionSelect = { selectedOption1 = it },
                                hint = "Пол"
                            )

                            var selectedOption2 by remember { mutableStateOf<Option?>(Option("Мужской")) }

                            AppSelector(
                                selectedOption = selectedOption2,
                                options = listOf(
                                    Option(label = "Мужской"),
                                    Option(label = "Женский")
                                ),
                                onOptionSelect = { selectedOption2 = it },
                                hint = "Пол"
                            )

                            Text(text = "Поиск", style = CustomTheme.typography.title1ExtraBold)
                            var searchFieldValue by rememberSaveable { mutableStateOf("") }

                            AppSearchField(
                                value = searchFieldValue,
                                onValueChange = { searchFieldValue = it },
                                hint = "Искать описание"
                            )

                            Text(text = "Кнопки", style = CustomTheme.typography.title1ExtraBold)

                            AppButton(
                                label = "Подтвердить",
                                onClick = {},
                                state = ButtonState.Big
                            )

                            AppButton(
                                label = "Подтвердить",
                                onClick = {},
                                state = ButtonState.Big,
                                enabled = false
                            )

                            OutlinedAppButton(
                                label = "Подтвердить",
                                onClick = {},
                                state = ButtonState.Big
                            )

                            SecondaryAppButton(
                                label = "Подтвердить",
                                onClick = {},
                                state = ButtonState.Big
                            )

                            AppButton(
                                label = "Добавить",
                                onClick = {},
                                state = ButtonState.Small
                            )

                            OutlinedAppButton(
                                label = "Убрать",
                                onClick = {},
                                state = ButtonState.Small
                            )

                            AppButton(
                                label = "Добавить",
                                onClick = {},
                                state = ButtonState.Small,
                                enabled = false
                            )

                            SecondaryAppButton(
                                label = "Подтвердить",
                                onClick = {},
                                state = ButtonState.Small
                            )

                            AppButton(
                                label = "Популярное",
                                onClick = {},
                                state = ButtonState.Chips
                            )

                            AppButton(
                                label = "Популярное",
                                onClick = {},
                                state = ButtonState.Chips,
                                enabled = false
                            )

                            CartButton(
                                onClick = {},
                                totalPrice = 500
                            )

                            LoginButton(
                                icon = CustomIcons.vk,
                                label = "Войти с VK",
                                onClick = {}
                            )

                            LoginButton(
                                icon = CustomIcons.yandex,
                                label = "Войти с Yandex",
                                onClick = {}
                            )

                            Row(horizontalArrangement = Arrangement.spacedBy(16.dp)) {
                                BubbleButton(
                                    state = BubbleButtonState.Small,
                                    icon = CustomIcons.back
                                )

                                BubbleButton(
                                    state = BubbleButtonState.Big,
                                    icon = CustomIcons.filter
                                )
                            }

                            var inCartFirst by rememberSaveable { mutableStateOf(false) }

                            Text(text = "Карточки", style = CustomTheme.typography.title1ExtraBold)

                            PrimaryCard(
                                title = "Рубашка Воскресенье для машинного \n" +
                                        "вязания",
                                category = "Мужская одежда",
                                price = 300,
                                inCart = inCartFirst,
                                onAddToCartClick = { inCartFirst = true },
                                onRemoveFromCartClick = { inCartFirst = false },
                            )

                            var inCartSecond by rememberSaveable { mutableStateOf(true) }

                            PrimaryCard(
                                title = "Рубашка Воскресенье для машинного \n" +
                                        "вязания",
                                category = "Мужская одежда",
                                price = 300,
                                inCart = inCartSecond,
                                onAddToCartClick = { inCartSecond = true },
                                onRemoveFromCartClick = { inCartSecond = false },
                            )

                            var currentQuantity by rememberSaveable { mutableIntStateOf(1) }
                            CartCard(
                                title = "Рубашка воскресенье для машинного вязания",
                                price = 300,
                                currentQuantity = currentQuantity,
                                onChangeQuantity = { currentQuantity = it }
                            )

                            ProjectCard(
                                title = "Мой первый проект",
                                dayElapsed = 2,
                                onOpenClick = {}
                            )

                            Text(text = "Хэдэр", style = CustomTheme.typography.title1ExtraBold)

                            BigHeader(
                                title = "Корзина",
                                startContent = {
                                    BubbleButton(
                                        state = BubbleButtonState.Small,
                                        icon = CustomIcons.back
                                    )
                                },
                                endContent = {
                                    Icon(
                                        painter = CustomIcons.delete,
                                        contentDescription = null,
                                        tint = CustomTheme.colors.inputIcon
                                    )
                                }
                            )

                            SmallHeader(
                                title = "Корзина",
                                startContent = {
                                    BubbleButton(
                                        state = BubbleButtonState.Small,
                                        icon = CustomIcons.back
                                    )
                                },
                                endContent = {
                                    Icon(
                                        painter = CustomIcons.delete,
                                        contentDescription = null,
                                        tint = CustomTheme.colors.inputIcon
                                    )
                                }
                            )

                            Spacer(Modifier.height(100.dp))
                        }
                    }
                }
            }
        }
    }
}