package com.example.core.component.button

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun AppButton(
    label: String, // Текст кнопки
    onClick: () -> Unit, // Действие на клик
    state: ButtonState, // Состояние
    modifier: Modifier = Modifier,
    enabled: Boolean = true
) {
    Box(contentAlignment = Alignment.Center, modifier = modifier) {
        val commonCondition = state is ButtonState.Chips
        Button(
            modifier = modifier
                .then(state.width())
                .height(state.height()),
            onClick = onClick,
            shape = RoundedCornerShape(10.dp),
            enabled = enabled,
            colors = ButtonDefaults.buttonColors().copy(
                containerColor = CustomTheme.colors.accent,
                disabledContainerColor = if (commonCondition) CustomTheme.colors.inputBg else CustomTheme.colors.accentInactive
            )
        ) {
        }
        Text(
            text = label,
            style = state.typography()
                .copy(
                    color = if (commonCondition && !enabled) CustomTheme.colors.description else CustomTheme.colors.white,
                    textAlign = TextAlign.Center
                ),
            maxLines = 1,
            overflow = TextOverflow.Ellipsis,
            modifier = Modifier
                .then(state.width())
                .padding(horizontal = state.padding()),
        )
    }
}