package com.example.core.component.button

import android.annotation.SuppressLint
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.width
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@SuppressLint("ModifierFactoryExtensionFunction")
interface ButtonState {

    fun width(): Modifier // т.к fillmaxWith не является конкретной шириной, то возвращаемый тип modifier

    fun height(): Dp // высота

    fun padding(): Dp // отступы основного текста кнопки от контейнера

    @Composable
    fun typography(): TextStyle

    object Big : ButtonState {

        override fun width(): Modifier = Modifier.fillMaxWidth()

        override fun height(): Dp = 56.dp

        override fun padding(): Dp = 0.dp

        @Composable
        override fun typography(): TextStyle = CustomTheme.typography.title3Semibold
    }

    object Small : ButtonState {

        override fun width(): Modifier = Modifier.width(98.dp)

        override fun height(): Dp = 40.dp

        override fun padding(): Dp = 13.5.dp

        @Composable
        override fun typography(): TextStyle = CustomTheme.typography.captionSemibold
    }

    object Chips : ButtonState {

        override fun width(): Modifier = Modifier.width(129.dp)

        override fun height(): Dp = 48.dp

        override fun padding(): Dp = 20.dp

        @Composable
        override fun typography(): TextStyle = CustomTheme.typography.textMedium
    }

    object Login : ButtonState {

        override fun width(): Modifier = Modifier.fillMaxWidth()

        override fun height(): Dp = 60.dp

        override fun padding(): Dp = 0.dp

        @Composable
        override fun typography(): TextStyle = CustomTheme.typography.title3Medium
    }
}