package com.example.core.component.button

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import com.example.core.R
import com.example.core.theme.CustomIcons
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun CartButton(
    onClick: () -> Unit,
    totalPrice: Int, // цена на кнопке
    modifier: Modifier = Modifier
) {
    val state = ButtonState.Big

    Box(contentAlignment = Alignment.CenterStart, modifier = modifier) {
        Button(
            modifier = modifier
                .then(state.width())
                .height(state.height()),
            onClick = onClick,
            shape = RoundedCornerShape(10.dp),
            colors = ButtonDefaults.buttonColors().copy(
                containerColor = CustomTheme.colors.accent,
                disabledContentColor = CustomTheme.colors.accentInactive
            )
        ) {
        }
        Row(verticalAlignment = Alignment.CenterVertically, modifier = Modifier.fillMaxWidth()) {

            Icon(
                painter = CustomIcons.cart,
                contentDescription = null,
                tint = CustomTheme.colors.white,
                modifier = Modifier.padding(horizontal = CustomTheme.elevation.spacing16dp)
            )

            Text(
                text = stringResource(R.string.in_cart),
                style = state.typography().copy(color = CustomTheme.colors.white)
            )

            Spacer(Modifier.weight(1f))

            Text(
                text = stringResource(R.string.total_price, totalPrice),
                style = state.typography().copy(color = CustomTheme.colors.white)
            )
            Spacer(Modifier.width(CustomTheme.elevation.spacing16dp))
        }
    }
}