package com.example.core.component.button

import androidx.compose.animation.animateColorAsState
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.VerticalDivider
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomIcons
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

/**
 * для установки цвета и обработки крайних случаев изменения по значению
 * в кнопке есть параметр количества */
@Composable
fun ChangeQuantityButton(
    currentQuantity: Int,
    onIncrementClick: () -> Unit, // обработка увеличения количества
    onDecrementClick: () -> Unit, // обработка уменьшения количества
    modifier: Modifier = Modifier
) {
    Box(
        contentAlignment = Alignment.Center,
        modifier = modifier
            .width(CustomTheme.elevation.spacing64dp)
            .height(CustomTheme.elevation.spacing32dp)
            .clip(RoundedCornerShape(8.dp))
            .background(CustomTheme.colors.inputBg)
    ) {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = Modifier.padding(horizontal = 6.dp)
        ) {
            val minusCondition = currentQuantity > 1
            val minusTint by animateColorAsState(if (minusCondition) CustomTheme.colors.placeholder else CustomTheme.colors.inputIcon)
            Icon(
                painter = CustomIcons.minus,
                contentDescription = null,
                tint = minusTint,
                modifier = Modifier.then(
                    if (minusCondition) {
                        Modifier.clickable(
                            interactionSource = remember { MutableInteractionSource() },
                            null,
                            onClick = onDecrementClick
                        )
                    } else Modifier
                )
            )

            VerticalDivider(
                thickness = 1.dp,
                color = CustomTheme.colors.inputStroke,
                modifier = Modifier.padding(
                    horizontal = 6.dp,
                    vertical = CustomTheme.elevation.spacing8dp
                )
            )

            val plusCondition = currentQuantity < 100
            val plusTint by animateColorAsState(if (plusCondition) CustomTheme.colors.placeholder else CustomTheme.colors.inputIcon)

            Icon(
                painter = CustomIcons.plus,
                contentDescription = null,
                tint = plusTint,
                modifier = Modifier.then(
                    if (plusCondition) {
                        Modifier.clickable(
                            interactionSource = remember { MutableInteractionSource() },
                            null,
                            onClick = onIncrementClick
                        )
                    } else Modifier
                )
            )
        }
    }
}