package com.example.core.component.button

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.OutlinedButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.painter.Painter
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun LoginButton(
    icon: Painter,
    label: String,
    onClick: () -> Unit,
    modifier: Modifier = Modifier
) {
    val state = ButtonState.Login

    OutlinedButton(
        modifier = modifier
            .then(state.width())
            .height(state.height()),
        onClick = onClick,
        shape = RoundedCornerShape(10.dp),
        border = BorderStroke(width = 1.dp, color = CustomTheme.colors.inputStroke)
    ) {
        Row(verticalAlignment = Alignment.CenterVertically) {
            Image(painter = icon, contentDescription = null)
            Spacer(Modifier.width(CustomTheme.elevation.spacing16dp))
            Text(text = label, style = state.typography())
        }
    }
}