package com.example.core.component.button

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.OutlinedButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun OutlinedAppButton(
    label: String,
    onClick: () -> Unit,
    state: ButtonState,
    modifier: Modifier = Modifier
) {
    Box(contentAlignment = Alignment.Center, modifier = modifier) {
        OutlinedButton(
            modifier = modifier
                .then(state.width())
                .height(state.height()),
            onClick = onClick,
            shape = RoundedCornerShape(10.dp),
            border = BorderStroke(width = 1.dp, color = CustomTheme.colors.accent)
        ) {
        }
        Text(
            text = label,
            style = state.typography()
                .copy(color = CustomTheme.colors.accent, textAlign = TextAlign.Center),
            maxLines = 1,
            overflow = TextOverflow.Ellipsis,
            modifier = Modifier.then(state.width()).padding(horizontal = state.padding())
        )
    }
}