package com.example.core.component.card

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import com.example.core.R
import com.example.core.component.button.ChangeQuantityButton
import com.example.core.theme.CustomIcons
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun CartCard(
    title: String,
    price: Int,
    currentQuantity: Int,
    onChangeQuantity: (Int) -> Unit,
    modifier: Modifier = Modifier
) {
    AppCardBackground(modifier = modifier) {
        Column {
            Row {
                Text(
                    text = title,
                    style = CustomTheme.typography.headlineMedium,
                    modifier = Modifier.weight(2f)
                )

                Row(horizontalArrangement = Arrangement.End, modifier = Modifier.weight(1f)) {
                    Icon(
                        painter = CustomIcons.close,
                        contentDescription = null,
                        tint = CustomTheme.colors.description
                    )
                }
            }
            Spacer(Modifier.height(34.dp))

            Row(verticalAlignment = Alignment.CenterVertically) {
                Text(
                    text = stringResource(R.string.total_price, price),
                    style = CustomTheme.typography.title3Medium,
                    modifier = Modifier.weight(1.7f)
                )

                Text(
                    text = stringResource(R.string.cart_card_quantity, currentQuantity),
                    style = CustomTheme.typography.textRegular
                )

                Row(modifier = Modifier.weight(1f), horizontalArrangement = Arrangement.End) {
                    /**
                     * обработка количества уже без дополнительных проверок */
                    ChangeQuantityButton(
                        currentQuantity = currentQuantity,
                        onIncrementClick = { onChangeQuantity(currentQuantity.inc()) },
                        onDecrementClick = { onChangeQuantity(currentQuantity.dec()) }
                    )
                }
            }
        }
    }
}