package com.example.core.component.card

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import com.example.core.R
import com.example.core.component.button.AppButton
import com.example.core.component.button.ButtonState
import com.example.core.component.button.OutlinedAppButton
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun PrimaryCard(
    title: String,
    category: String,
    price: Int,
    inCart: Boolean,
    onAddToCartClick: () -> Unit,
    onRemoveFromCartClick: () -> Unit,
    modifier: Modifier = Modifier
) {
    AppCardBackground(modifier = modifier) {
        Column {
            Text(text = title, style = CustomTheme.typography.headlineMedium)
            Spacer(Modifier.height(CustomTheme.elevation.spacing16dp))
            Row(verticalAlignment = Alignment.CenterVertically) {
                Column(modifier = Modifier.weight(1f)) {
                    Text(
                        text = category,
                        style = CustomTheme.typography.captionSemibold.copy(
                            color = CustomTheme.colors.placeholder
                        )
                    )

                    Spacer(Modifier.height(CustomTheme.elevation.spacing4dp))
                    Text(
                        text = stringResource(R.string.total_price, price),
                        style = CustomTheme.typography.title3Semibold
                    )
                }

                if (inCart) {
                    OutlinedAppButton(
                        label = stringResource(R.string.drop),
                        onClick = onRemoveFromCartClick,
                        state = ButtonState.Small
                    )
                } else {
                    AppButton(
                        label = stringResource(R.string.add),
                        onClick = onAddToCartClick,
                        state = ButtonState.Small
                    )
                }
            }
        }
    }
}