package com.example.core.component.card

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.pluralStringResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.unit.dp
import com.example.core.R
import com.example.core.component.button.AppButton
import com.example.core.component.button.ButtonState
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun ProjectCard(
    title: String,
    dayElapsed: Int,
    onOpenClick: () -> Unit,
    modifier: Modifier = Modifier
) {
    AppCardBackground(modifier = modifier) {
        Column {
            Text(text = title, style = CustomTheme.typography.headlineMedium)
            Spacer(Modifier.height(44.dp))
            Row(verticalAlignment = Alignment.Bottom) {
                Text(
                    text = pluralStringResource(R.plurals.elapsed_days, dayElapsed, dayElapsed),
                    style = CustomTheme.typography.captionSemibold.copy(
                        color = CustomTheme.colors.placeholder
                    ),
                    modifier = Modifier.weight(1f)
                )

                AppButton(
                    label = stringResource(R.string.open),
                    onClick = onOpenClick,
                    state = ButtonState.Small
                )
            }
        }
    }
}