package com.example.core.component.search

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.focus.FocusRequester
import androidx.compose.ui.focus.focusRequester
import androidx.compose.ui.focus.onFocusChanged
import androidx.compose.ui.graphics.SolidColor
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomIcons
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun AppSearchField(
    value: String,
    onValueChange: (String) -> Unit,
    hint: String,
    modifier: Modifier = Modifier
) {
    val focusRequester = remember { FocusRequester() }

    var hasFocus by rememberSaveable { mutableStateOf(false) }

    Box(
        contentAlignment = Alignment.CenterStart,
        modifier = Modifier
            .fillMaxWidth()
            .height(CustomTheme.elevation.spacing48dp)
            .clip(RoundedCornerShape(10.dp))
            .background(CustomTheme.colors.inputBg)
            .border(
                width = 1.dp,
                color = CustomTheme.colors.inputStroke,
                shape = RoundedCornerShape(10.dp)
            )
    ) {
        Column(modifier = modifier) {
            Row(modifier = Modifier.fillMaxSize(), verticalAlignment = Alignment.CenterVertically) {
                Spacer(Modifier.width(14.dp))
                Icon(
                    painter = CustomIcons.search,
                    tint = CustomTheme.colors.description,
                    contentDescription = null
                )
                Spacer(Modifier.width(CustomTheme.elevation.spacing8dp))

                Box(contentAlignment = Alignment.CenterStart, modifier = Modifier.weight(1f)) {

                    if (value.isEmpty()) {
                        Text(
                            text = hint,
                            style = CustomTheme.typography.textRegular.copy(
                                color = CustomTheme.colors.placeholder
                            )
                        )
                    }

                    BasicTextField(
                        value = value,
                        onValueChange = onValueChange,
                        singleLine = true,
                        cursorBrush = SolidColor(CustomTheme.colors.accent),
                        textStyle = CustomTheme.typography.textRegular,
                        modifier = Modifier
                            .fillMaxWidth()
                            .focusRequester(focusRequester)
                            .onFocusChanged { focusState ->
                                hasFocus = focusState.hasFocus
                            }
                    )
                }
                if (hasFocus) {
                    Icon(
                        painter = CustomIcons.close,
                        contentDescription = null,
                        tint = CustomTheme.colors.description,
                        modifier = Modifier.clickable(
                            interactionSource = remember { MutableInteractionSource() },
                            indication = null
                        ) { onValueChange("") }
                    )

                    Spacer(Modifier.width(14.dp))
                }
            }
        }
    }
}