package com.example.core.component.select

import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.SheetState
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomIcons
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

/**
 * общее диалоговое окно
* */
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun AppBottomSheet(
    sheetState: SheetState, // состояние, для управлением отображения
    onDismissRequest: () -> Unit, // обработка запроса на закрытие
    modifier: Modifier = Modifier,
    content: @Composable () -> Unit // контент
) {
    ModalBottomSheet(
        sheetState = sheetState,
        onDismissRequest = onDismissRequest,
        dragHandle = null,
        containerColor = CustomTheme.colors.white,
        modifier = modifier
    ) {
        Column(
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 20.dp)
        ) {
            Spacer(Modifier.height(CustomTheme.elevation.spacing24dp))
            Box {
                Image(
                    painter = CustomIcons.closeSheet,
                    contentDescription = null,
                    modifier = Modifier.align(Alignment.TopEnd)
                )

                content()
            }
            Spacer(Modifier.height(84.dp))
        }
    }
}