package com.example.core.component.tabbar

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.HorizontalDivider
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import com.example.core.theme.CustomTheme

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Composable
fun BottomTabBar(
    tabs: List<BottomTab>,
    hierarchy: Sequence<String?>?,
    onTabClick: (BottomTab) -> Unit,
    bottomPadding: Dp,
    modifier: Modifier = Modifier
) {
    Column(
        modifier = modifier
            .fillMaxWidth()
            .background(CustomTheme.colors.white)
    ) {
        Column(
            modifier = Modifier
                .fillMaxWidth()
                .height(67.dp)
                .offset(y = -bottomPadding)
                .background(CustomTheme.colors.white)
                .clickable(interactionSource = remember { MutableInteractionSource() }, null) {  }

        ) {
            HorizontalDivider(thickness = 1.dp, color = Color(0xFFA0A0A0).copy(alpha = 0.3f))

            Row(
                horizontalArrangement = Arrangement.SpaceAround,
                modifier = Modifier.fillMaxWidth().padding(vertical = 8.dp)
            ) {
                tabs.forEach { tab ->
                    BottomTabBarItem(
                        bottomTab = tab,
                        selected = hierarchy?.any { it == tab::class.qualifiedName } ?: false,
                        modifier = Modifier.clickable(
                            interactionSource = remember { MutableInteractionSource() },
                            indication = null
                        ) {
                            onTabClick(tab)
                        }
                    )
                }
            }
        }
    }
}