package com.example.core.theme

import androidx.compose.runtime.Composable
import androidx.compose.runtime.CompositionLocalProvider
import androidx.compose.runtime.Immutable
import androidx.compose.runtime.staticCompositionLocalOf
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp

/**
 * Автор: Манякин Дмитрий (user5)
 * Дата создания: 26.05.2025
 * */

@Immutable
data class CustomColors(
    val accent: Color,
    val accentInactive: Color,
    val black: Color,
    val white: Color,
    val error: Color,
    val success: Color,
    val inputBg: Color,
    val inputStroke: Color,
    val inputIcon: Color,
    val placeholder: Color,
    val description: Color,
    val cardStroke: Color
)

@Immutable
data class CustomTypography(
    val title1SemiBold: TextStyle,
    val title1ExtraBold: TextStyle,
    val title2Regular: TextStyle,
    val title2SemiBold: TextStyle,
    val title2ExtraBold: TextStyle,
    val title3Regular: TextStyle,
    val title3Medium: TextStyle,
    val title3Semibold: TextStyle,
    val headlineRegular: TextStyle,
    val headlineMedium: TextStyle,
    val textRegular: TextStyle,
    val textMedium: TextStyle,
    val captionRegular: TextStyle,
    val captionSemibold: TextStyle,
    val caption2Regular: TextStyle,
    val caption2Bold: TextStyle
)

@Immutable
data class CustomElevation(
    val spacing4dp: Dp,
    val spacing8dp: Dp,
    val spacing12dp: Dp,
    val spacing16dp: Dp,
    val spacing20dp: Dp,
    val spacing24dp: Dp,
    val spacing32dp: Dp,
    val spacing40dp: Dp,
    val spacing48dp: Dp,
    val spacing56dp: Dp,
    val spacing64dp: Dp
)

val LocalCustomColors = staticCompositionLocalOf {
    CustomColors(
        accent = Color.Unspecified,
        accentInactive = Color.Unspecified,
        black = Color.Unspecified,
        white = Color.Unspecified,
        error = Color.Unspecified,
        success = Color.Unspecified,
        inputBg = Color.Unspecified,
        inputStroke = Color.Unspecified,
        inputIcon = Color.Unspecified,
        placeholder = Color.Unspecified,
        description = Color.Unspecified,
        cardStroke = Color.Unspecified
    )
}

val LocalCustomTypography = staticCompositionLocalOf {
    CustomTypography(
        title1SemiBold = TextStyle.Default,
        title1ExtraBold = TextStyle.Default,
        title2Regular = TextStyle.Default,
        title2SemiBold = TextStyle.Default,
        title2ExtraBold = TextStyle.Default,
        title3Regular = TextStyle.Default,
        title3Medium = TextStyle.Default,
        title3Semibold = TextStyle.Default,
        headlineRegular = TextStyle.Default,
        headlineMedium = TextStyle.Default,
        textRegular = TextStyle.Default,
        textMedium = TextStyle.Default,
        captionRegular = TextStyle.Default,
        captionSemibold = TextStyle.Default,
        caption2Regular = TextStyle.Default,
        caption2Bold = TextStyle.Default
    )
}

val LocalCustomElevation = staticCompositionLocalOf {
    CustomElevation(
        spacing4dp = Dp.Unspecified,
        spacing8dp = Dp.Unspecified,
        spacing12dp = Dp.Unspecified,
        spacing16dp = Dp.Unspecified,
        spacing20dp = Dp.Unspecified,
        spacing24dp = Dp.Unspecified,
        spacing32dp = Dp.Unspecified,
        spacing40dp = Dp.Unspecified,
        spacing48dp = Dp.Unspecified,
        spacing56dp = Dp.Unspecified,
        spacing64dp = Dp.Unspecified
    )
}

@Composable
fun CustomTheme(content: @Composable () -> Unit) {

    val customColors = CustomColors(
        accent = Accent,
        accentInactive = AccentInactive,
        black = Black,
        white = White,
        error = Error,
        success = Success,
        inputBg = InputBg,
        inputStroke = InputStroke,
        inputIcon = InputIcon,
        placeholder = Placeholder,
        description = Description,
        cardStroke = CardStroke
    )

    val customTypography = CustomTypography(
        title1SemiBold = Title1SemiBold,
        title1ExtraBold = Title1ExtraBold,
        title2Regular = Title2Regular,
        title2SemiBold = Title2SemiBold,
        title2ExtraBold = Title2ExtraBold,
        title3Regular = Title3Regular,
        title3Medium = Title3Medium,
        title3Semibold = Title3Semibold,
        headlineRegular = HeadlineRegular,
        headlineMedium = HeadlineMedium,
        textRegular = TextRegular,
        textMedium = TextMedium,
        captionRegular = CaptionRegular,
        captionSemibold = CaptionSemibold,
        caption2Regular = Caption2Regular,
        caption2Bold = Caption2Bold
    )

    val customElevation = CustomElevation(
        spacing4dp = 4.dp,
        spacing8dp = 8.dp,
        spacing12dp = 12.dp,
        spacing16dp = 16.dp,
        spacing20dp = 20.dp,
        spacing24dp = 24.dp,
        spacing32dp = 32.dp,
        spacing40dp = 40.dp,
        spacing48dp = 48.dp,
        spacing56dp = 56.dp,
        spacing64dp = 64.dp
    )

    CompositionLocalProvider(
        LocalCustomColors provides customColors,
        LocalCustomTypography provides customTypography,
        LocalCustomElevation provides customElevation,
        content = content
    )
}

object CustomTheme {
    
    val colors: CustomColors
        @Composable get() = LocalCustomColors.current

    val typography: CustomTypography
        @Composable get() = LocalCustomTypography.current

    val elevation: CustomElevation
        @Composable get() = LocalCustomElevation.current
}